"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const service_1 = require("../../principal/service");
const html_1 = require("../formats/html");
const crypto_1 = require("../../crypto");
class CreateGroupController extends controller_1.default {
    async get(ctx) {
        ctx.privileges.require('admin');
        ctx.response.type = 'text/html';
        ctx.response.body = (0, html_1.createGroupForm)({
            csrfToken: await ctx.getCsrf(),
            msg: ctx.query.msg,
            error: ctx.query.error
        });
    }
    async post(ctx) {
        const principalService = new service_1.PrincipalService(ctx.privileges);
        ctx.request.validate('https://curveballjs.org/schemas/a12nserver/group-new-form.json');
        ctx.privileges.require('admin');
        const nickname = ctx.request.body.nickname;
        const newGroup = await principalService.save({
            type: 'group',
            nickname,
            active: true,
            identity: (0, crypto_1.uuidUrn)(),
            createdAt: new Date(),
            modifiedAt: new Date(),
        });
        ctx.response.status = 303;
        ctx.response.headers.set('Location', newGroup.href);
    }
}
exports.default = new CreateGroupController();
//# sourceMappingURL=new.js.map