"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const http_errors_1 = require("@curveball/http-errors");
const csv = require("../formats/csv");
const service_1 = require("../../principal/service");
const oauth2Service = require("../service");
const oauth2ClientService = require("../../oauth2-client/service");
class ActiveSessions extends controller_1.default {
    async getCsv(ctx) {
        const [, tokens, clients] = await this.getData(ctx);
        ctx.status = 200;
        ctx.response.type = 'text/csv';
        ctx.response.body = csv.activeSessions(tokens, clients);
        ctx.response.links.add({
            rel: 'alternate',
            href: ctx.path,
            type: 'application/json',
        });
    }
    async getHal(ctx) {
        throw new http_errors_1.NotImplemented('This feature is not yet implemented');
    }
    async getData(ctx) {
        const principalService = new service_1.PrincipalService(ctx.privileges);
        const principal = await principalService.findByExternalId(ctx.params.id);
        if (ctx.auth.equals(principal) && !ctx.privileges.has('admin')) {
            throw new http_errors_1.Forbidden('You can only use this API for yourself yourself, or if you have \'admin\' privileges');
        }
        if (!assertNotGroup(principal)) {
            throw new http_errors_1.NotFound('This endpoint only exists for users and apps');
        }
        const tokens = await oauth2Service.getActiveTokens(principal);
        const clients = new Map();
        for (const token of tokens) {
            if (token.clientId !== 0 && !clients.has(token.clientId)) {
                try {
                    const client = await oauth2ClientService.findById(token.clientId);
                    clients.set(token.clientId, client);
                }
                catch (e) {
                    if (e instanceof http_errors_1.NotFound) {
                        console.warn('Encountered an active token in the database, with no associated oauth2 client');
                        clients.set(token.clientId, null);
                    }
                    else {
                        throw e;
                    }
                }
            }
        }
        return [principal, tokens, clients];
    }
}
__decorate([
    (0, controller_1.accept)('text/csv'),
    (0, controller_1.method)('GET')
], ActiveSessions.prototype, "getCsv", null);
__decorate([
    (0, controller_1.accept)('json'),
    (0, controller_1.method)('GET')
], ActiveSessions.prototype, "getHal", null);
function assertNotGroup(input) {
    return ['user', 'app'].includes(input.type);
}
exports.default = new ActiveSessions();
//# sourceMappingURL=active-sessions.js.map