"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPublicKey = exports.generateJWTIDToken = exports.generateJWTAccessToken = void 0;
const crypto_1 = require("../crypto");
const server_settings_1 = require("../server-settings");
const crypto_2 = require("crypto");
const jose_1 = require("jose");
const kernel_1 = require("@curveball/kernel");
async function generateJWTAccessToken(options) {
    const jti = await (0, crypto_1.generateSecretToken)();
    const privateKey = getPrivateKey();
    const jwt = await new jose_1.SignJWT({
        scope: options.scope.join(' '),
        client_id: options.client.clientId,
    })
        .setProtectedHeader({
        alg: 'RS256',
        typ: 'at+jwt',
    })
        .setIssuedAt()
        .setIssuer((0, kernel_1.getGlobalOrigin)())
        .setAudience(options.client.app.href)
        .setSubject(options.principal.href)
        .setExpirationTime(Math.floor(Date.now() / 1000) + options.expiry)
        .setJti(jti)
        .sign(privateKey);
    return jwt;
}
exports.generateJWTAccessToken = generateJWTAccessToken;
async function generateJWTIDToken(options) {
    const privateKey = getPrivateKey();
    const jwt = await new jose_1.SignJWT({
        nonce: options.nonce,
    })
        .setProtectedHeader({
        alg: 'RS256',
    })
        .setIssuedAt()
        .setIssuer((0, kernel_1.getGlobalOrigin)())
        .setAudience(options.client.clientId)
        .setSubject(options.principal.href)
        .setExpirationTime(Math.floor(Date.now() / 1000) + (0, server_settings_1.getSetting)('oidc.idToken.expiry'))
        .sign(privateKey);
    return jwt;
}
exports.generateJWTIDToken = generateJWTIDToken;
let privateKey;
function getPrivateKey() {
    if (privateKey) {
        return privateKey;
    }
    privateKey = (0, crypto_2.createPrivateKey)(getRawPrivateKey());
    return privateKey;
}
let publicKey;
function getPublicKey() {
    if (publicKey)
        return publicKey;
    publicKey = (0, crypto_2.createPublicKey)({
        key: getRawPrivateKey()
    });
    return publicKey;
}
exports.getPublicKey = getPublicKey;
function getRawPrivateKey() {
    const key = (0, server_settings_1.getSetting)('jwt.privateKey');
    if (!key) {
        throw new Error('The JWT_PRIVATE_KEY environment variable must be set, and must be a RSA private key file (typically a .pem file)');
    }
    // Some environment variable systems will convert the newline to a literal '\n'.
    // this is a safe operation, because the file should not contain any literal
    // backslashes.
    return Buffer.from(key.replace(/\\n/gm, '\n'));
}
//# sourceMappingURL=jwt.js.map