"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const controller_1 = require("@curveball/controller");
const http_errors_1 = require("@curveball/http-errors");
const server_settings_1 = require("../../server-settings");
const service_1 = require("../../principal/service");
const userService = require("../../user/service");
const html_1 = require("../formats/html");
const privilegeService = require("../../privilege/service");
class UserRegistrationController extends controller_1.default {
    async get(ctx) {
        const firstRun = !(await (0, service_1.hasUsers)());
        ctx.response.type = 'text/html';
        ctx.response.body = (0, html_1.registrationForm)(ctx.query.msg, ctx.query.error, (0, server_settings_1.getSetting)('registration.mfa.enabled'), firstRun, ctx.query.continue);
    }
    async post(ctx) {
        const firstRun = !(await (0, service_1.hasUsers)());
        const body = ctx.request.body;
        const userPassword = body.password;
        const confirmPassword = body.confirmPassword;
        const addMfa = 'addMfa' in body;
        /**
         * We use an 'insecure' context for registration because it's anonymous
         */
        const principalService = new service_1.PrincipalService('insecure');
        if (userPassword !== confirmPassword) {
            ctx.status = 303;
            ctx.response.headers.set('Location', '/register?' + new URLSearchParams({
                error: 'Password mismatch. Please try again',
                ...(body.continue ? { continue: body.continue } : {})
            }));
            return;
        }
        try {
            await principalService.findByIdentity('mailto:' + body.emailAddress);
            ctx.status = 303;
            ctx.response.headers.set('Location', '/register?' + new URLSearchParams({
                error: 'User with this email adddress already exists',
                ...(body.continue ? { continue: body.continue } : {})
            }));
            return;
        }
        catch (err) {
            if (!(err instanceof http_errors_1.NotFound)) {
                throw err;
            }
        }
        const user = await principalService.save({
            identity: 'mailto:' + body.emailAddress,
            nickname: body.nickname,
            createdAt: new Date(),
            modifiedAt: new Date(),
            type: 'user',
            // Auto-activating if it's the first user.
            active: firstRun,
        });
        if (firstRun) {
            // The first user will be an admin
            await privilegeService.addPrivilegeForUser(user, 'admin', '*');
        }
        await userService.createPassword(user, userPassword);
        if (addMfa && (0, server_settings_1.getSetting)('registration.mfa.enabled')) {
            ctx.session = {
                registerUser: user,
                registerContinueUrl: body.continue,
            };
            ctx.response.status = 303;
            ctx.response.headers.set('Location', '/register/mfa');
            return;
        }
        ctx.status = 303;
        if (body.continue) {
            ctx.response.headers.set('Location', body.continue);
        }
        else {
            ctx.response.headers.set('Location', '/login?msg=Registration+successful.+Please log in');
        }
    }
    async dispatch(ctx) {
        if (!(0, server_settings_1.getSetting)('registration.enabled')) {
            throw new http_errors_1.Forbidden('This feature is disabled');
        }
        return super.dispatch(ctx);
    }
}
exports.default = new UserRegistrationController();
//# sourceMappingURL=user.js.map